Scrapple 0.1 documentation — Scrapple 0.1 documentation

### Navigation

- index
- next |
- Scrapple 0.1 documentation »

# Scrapple 0.1 documentation

Scrapple is a project aimed at designing a framework for building web content extractors. This documentation contains details about using Scrapple and a description of how Scrapple works.

## Overview

Introducing Scrapple
  An introduction to Scrapple
Install Scrapple
  Instructions for installing Scrapple and the required dependencies
Scrapple tutorial
  An intoductory tutorial to using Scrapple for generating the required scrapers/crawlers

## Concepts

Scrapple commands
  Commands provided by the Scrapple CLI
Configuration file
  The configuration file which is used by Scrapple to implement the required extractor/crawler

## Contribution guide

This part contains information about contributing to the project.

Authors
  Contributors to the project
Contributing
  Details about contributing to Scrapple

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Scrapple 0.1 documentation »